/*!	\file		TT_main5.c
	\author		Garth Santor
	\date		2020-02-26
	\version	1.0.0

	Temperature Table with optional user input.
*/

#include <stdio.h>
#include <math.h>
#include <stdbool.h>



/*!	Fahrenheit to Celsius conversion.
	\param Fahrenheit temperature.
	\return Celsuis equivalent temperature.
*/
inline double fahr2cel(double farhenheit) {
	return 5.0 / 9.0 * (farhenheit - 32.0);
}


/*!	Number of Whole Digits.
	\param any real number.
	\return The number of decimal digits of the whole number part.
*/
inline unsigned num_whole_digits(double number) {
	return (unsigned)floor(log10(fabs(number))) + 1;
}


/*!	max_u
	\param an unsigned number
	\param an unsigned number
	\return the greater of the two unsigned values.
*/
inline unsigned max_u(unsigned a, unsigned b) {
	return a > b ? a : b;
}


int main() {
	// Get table parameters from the user
	puts("Temperature Table 1.0.0, (c) 2020, Garth Santor");
	printf("Enter a low and high Fahrenheit temperature and interval: ");

#define MAX_LINE 100
	char line[MAX_LINE] = { 0 };
	gets_s(line, MAX_LINE);

	double startF = -40;
	double endF = 140.0;
	double intervalF = 5.0;
	int nParams = sscanf_s(line, "%lf %lf %lf", &startF, &endF, &intervalF);
	switch (nParams) {
	case 1:
		endF = startF;
		startF = 0;
	case 2:
		intervalF = 1.0;
	}

	// correct interval direction
	intervalF = fabs(intervalF);
	if (startF > endF) {
		intervalF = -intervalF;
	}

	// Output the table
	bool descendingTable = intervalF < 0;

	// measure longest output numbers
	const unsigned maxDF = max_u(num_whole_digits(startF), num_whole_digits(endF));
	const unsigned maxDC = max_u(num_whole_digits(fahr2cel(startF)), num_whole_digits(fahr2cel(endF)));

	putchar('\n');
	for (double tempF = startF; descendingTable ? tempF >= endF : tempF <= endF; tempF += intervalF)
		printf("%*.1lf F %*.1lf C\n", maxDF + 3, tempF, maxDC + 3, fahr2cel(tempF));
}